summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorPrincess of Sleeping2021-01-04 12:01:17 +0900
committerReiko Asakura2021-01-04 12:01:17 +0900
commit23dbcaa6d3dc8c10c474069380edf11603cac75c (patch)
tree98f08c8e713af4c919b8fe29da6a8b33a803692f /include
parentAdd gxm and gpu internal functions (diff)
downloadvds-libraries-23dbcaa6d3dc8c10c474069380edf11603cac75c.tar.gz
Fix ScePower NIDs and prototype
Diffstat (limited to 'include')
-rw-r--r--include/kernel/power.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/kernel/power.h b/include/kernel/power.h
index b56731b..82308e0 100644
--- a/include/kernel/power.h
+++ b/include/kernel/power.h
@@ -152,11 +152,11 @@ int scePowerGetArmClockFrequency(void);
int scePowerGetBusClockFrequency(void);
/**
* Returns GPU clock frequency
*
* @return GPU clock frequency in Mhz
*/
-int scePowerGetGpuClockFrequency(void);
+int scePowerGetSysClockFrequency(void);
/**
* Returns GPU crossbar clock frequency
@@ -152,11 +152,11 @@ int scePowerGetArmClockFrequency(void);
int scePowerGetBusClockFrequency(void);
/**
- * Returns GPU clock frequency
+ * Returns Sys clock frequency
*
@@ -152,11 +152,11 @@ int scePowerGetArmClockFrequency(void);
*
- * @return GPU clock frequency in Mhz
+ * @return Sys clock frequency in Mhz
*/